---
title: RTL Support
page_title: RTL Support - DropDownTree - Kendo UI for Vue
description: "Explore the RTL support offered by the Kendo UI DropDownTree wrapper for Vue."
slug: rtl_dropdowntree
position: 6
---

# RTL Support

You can activate the right-to-left functionality by adding the `k-rtl` class to the container of the DropDownTree.

The following example demonstrates how to utilize the RTL support for the DropDownTree.

{% meta height:400 %}
```html-preview
<div id="vueapp" class="vue-app k-rtl">      
            <kendo-dropdowntree ref="dropdowntree"
                    :data-source="dataSource"
                    :filter="'contains'"
                    style="width: 300px;">
            </kendo-dropdowntree>
</div>

<style>
    #treeview .k-sprite {
        background-image: url("https://demos.telerik.com/kendo-ui/content/web/treeview/coloricons-sprite.png");
    }

    .rootfolder { background-position: 0 0; }
    .folder     { background-position: 0 -16px; }
    .pdf        { background-position: 0 -32px; }
    .html       { background-position: 0 -48px; }
    .image      { background-position: 0 -64px; }
</style>
```
```js
Vue.use(DropDownTreeInstaller);

new Vue({
    el: "#vueapp",
    data () {
        return {
            dataSource: [{
                id: 1, text: "My Documents", expanded: true, spriteCssClass: "rootfolder", items: [
                    {
                        id: 2, text: "Kendo UI Project", expanded: true, spriteCssClass: "folder", items: [
                            { id: 3, text: "about.html", spriteCssClass: "html" },
                            { id: 4, text: "index.html", spriteCssClass: "html" },
                            { id: 5, text: "logo.png", spriteCssClass: "image" }
                        ]
                    },
                    {
                        id: 6, text: "New Web Site", expanded: true, spriteCssClass: "folder", items: [
                            { id: 7, text: "mockup.jpg", spriteCssClass: "image" },
                            { id: 8, text: "Research.pdf", spriteCssClass: "pdf" },
                        ]
                    },
                    {
                        id: 9, text: "Reports", expanded: true, spriteCssClass: "folder", items: [
                            { id: 10, text: "February.pdf", spriteCssClass: "pdf" },
                            { id: 11, text: "March.pdf", spriteCssClass: "pdf" },
                            { id: 12, text: "April.pdf", spriteCssClass: "pdf" }
                        ]
                    }
                ]
            }]
        }
    }
})
```
{% endmeta %}

## Suggested Links

* [Kendo UI DropDownTree for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/dropdowntree/overview)
* [API Reference of the DropDownTree Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdowntree)
